<?php
declare(strict_types=1);

namespace FiloBlu\Refilo\Observer;

use Exception;
use Magento\Catalog\Api\Data\CategoryInterface;
use Magento\Catalog\Model\Category;
use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Eav\Api\AttributeRepositoryInterface;
use Magento\Framework\App\ResourceConnection;
use Magento\Framework\Exception\NoSuchEntityException;

/**
 *
 */
class CategorySaveAfterObserver implements ObserverInterface
{

    /** @var AttributeRepositoryInterface */
    protected $attributeRepository;

    /** @var ResourceConnection */
    protected $resourceConnection;

    public function __construct(
        AttributeRepositoryInterface $attributeRepository,
        ResourceConnection           $resourceConnection
    )
    {
        $this->attributeRepository = $attributeRepository;
        $this->resourceConnection = $resourceConnection;
    }

    /**
     * @param Observer $observer
     * @throws Exception
     */
    public function execute(Observer $observer)
    {
        try {
            $attributeId = $this->attributeRepository->get(Category::ENTITY, 'refilo_exclude_from_search')->getAttributeId();
        } catch (NoSuchEntityException $noSuchEntityException) {
            return;
        }

        if (!$attributeId) {
            return;
        }

        /** @var CategoryInterface|Category $category */
        $category = $observer->getData('category');
        $value = (int)$category->getData('refilo_exclude_from_search');
        $storeId = $category->getStoreId();
        $childrenIds = implode(',', $category->getChildrenCategories()->getAllIds());

        $connection = $this->resourceConnection->getConnection();
        $connection->update(
            'catalog_category_entity_int',
            ['value' => $value],
            "attribute_id = {$attributeId} AND row_id in ({$childrenIds}) AND store_id = {$storeId}"
        );

    }

}
